//
//  PickerViewController.swift
//  VoltageRatioInput
//
//  Created by Phidgets on 2018-01-25.
//  Copyright © 2018 Phidgets. All rights reserved.
//

import UIKit
import Phidget22Swift

class PickerViewController: UIViewController, UIPickerViewDelegate, UIPickerViewDataSource {
    
    @IBOutlet var pickerTitle: UILabel!
    @IBOutlet var pickerBox: UIView!
    @IBOutlet var pickerView: UIPickerView!
    var pickerArray = [String]()
    var titleName = String()
    var ch = VoltageRatioInput()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        pickerBox.layer.cornerRadius = 5
        pickerBox.layer.masksToBounds = true
        pickerTitle.text = titleName
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return pickerArray.count
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return pickerArray[row]
    }
    
    func pickerView(_ pickerView: UIPickerView, viewForRow row: Int, forComponent component: Int, reusing view: UIView?) -> UIView {
        var text = (view as? UILabel)
        if text == nil{
            text = UILabel.init()
        }
        text?.font = UIFont.systemFont(ofSize: 25, weight: UIFont.Weight.light)
        text?.textAlignment = .center
        text?.adjustsFontSizeToFitWidth = true
        text?.text = self.pickerView(pickerView, titleForRow: row, forComponent: component)
        
        return text!
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        let resultString:String = (pickerArray[row])
        do{
            if resultString == "Generic ratiometric sensor"{
                try ch.setSensorType(VoltageRatioSensorType.voltageRatio)
                return
            }
            else if resultString == "1101 - IR Distance Adapter, with Sharp Distance Sensor 2D120X (4-30cm)"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1101_Sharp2D120X)
                return
            }
            else if resultString == "1101 - IR Distance Adapter, with Sharp Distance Sensor 2Y0A21 (10-80cm)"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1101_Sharp2Y0A21)
                return
            }
            else if resultString == "1101 - IR Distance Adapter, with Sharp Distance Sensor 2Y0A02 (20-150cm)"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1101_Sharp2Y0A02)
                return
            }
            else if resultString == "1118 - 50Amp Current Sensor AC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1118_AC)
                return
            }
            else if resultString == "1118 - 50Amp Current Sensor DC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1118_DC)
                return
            }
            else if resultString == "1119 - 20Amp Current Sensor AC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1119_AC)
                return
            }
            else if resultString == "1119 - 20Amp Current Sensor DC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1119_DC)
                return
            }
            else if resultString == "1122 - 30 Amp Current Sensor AC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1122_AC)
                return
            }
            else if resultString == "1122 - 30 Amp Current Sensor DC"{
                try ch.setSensorType(VoltageRatioSensorType.PN_1122_DC)
                return
            }
            else if resultString == "1x" {
                try ch.setBridgeGain(BridgeGain.gain_1x)
                return
            }
            else if resultString == "2x"{
                try ch.setBridgeGain(BridgeGain.gain_2x)
                return
            }
            else if resultString == "4x"{
                try ch.setBridgeGain(BridgeGain.gain_4x)
                return
            }
            else if resultString == "8x"{
                try ch.setBridgeGain(BridgeGain.gain_8x)
                return
            }
            else if resultString == "16x"{
                try ch.setBridgeGain(BridgeGain.gain_16x)
                return
            }
            else if resultString == "32x"{
                try ch.setBridgeGain(BridgeGain.gain_32x)
                return
            }
            else if resultString == "64x"{
                try ch.setBridgeGain(BridgeGain.gain_64x)
                return
            }
            else if resultString == "128x"{
                try ch.setBridgeGain(BridgeGain.gain_128x)
                return
            }
            //use number to differentiate the rest
            let stringArray = resultString.components(
                separatedBy: CharacterSet.decimalDigits.inverted)
            let s1:String = stringArray[0]
            let sensorType = VoltageRatioSensorType(rawValue: UInt32(10) * UInt32(s1)!)
            try ch.setSensorType(sensorType!)
        } catch let err as PhidgetError {
            outputErrorMessage(errorTitle: "Error Code: \(err.errorCode)", errorMessage: err.description)
        } catch {
            print (error)
        }
        
    }
    
    @IBAction func done(_ sender: AnyObject) {
        self.performSegue(withIdentifier: "digitalOutputDoneSegue", sender: self)
    }
    
    var timeStamp:TimeInterval = 0
    var lastTimeStamp:TimeInterval = 0
    func outputErrorMessage(errorTitle:String, errorMessage:String){
        timeStamp = NSDate.timeIntervalSinceReferenceDate
        //Add a delay for error events so the user does not get bombarded by error events
        if(timeStamp - lastTimeStamp > 5){
            let alert = UIAlertController(title: errorTitle, message: errorMessage, preferredStyle: .alert)
            alert.addAction(UIAlertAction(title: "OK", style: .default, handler: {action -> Void in
            }))
            self.present(alert, animated: true, completion: nil)
            lastTimeStamp = timeStamp
        }
    }
    
}
